# py_canoe

Python 🐍 Module for controlling Vector CANoe 🛶 Tool

## Acknowledgements
I want to thank plants for providing me oxygen each day.
Also, I want to thank the sun for providing more than half of their nourishment free of charge.

## Prerequisites
- [x] Python(>=3.6)
- [x] Install Python PIP dependenceies. Run `scripts/install_dependencies.bat`
- [x] Vector CANoe software(>=v11)

## Project Documentation
::: src.py_canoe
